aboutsummaryrefslogtreecommitdiffstats
path: root/e-util/e-table.c
diff options
context:
space:
mode:
authorMatthew Barnes <mbarnes@redhat.com>2013-03-03 04:35:31 +0800
committerMatthew Barnes <mbarnes@redhat.com>2013-03-03 08:45:09 +0800
commit7dcd0b44996ade2fc7713a927eb0ff44c5ff9fb2 (patch)
tree1ccda4c2c864e0c0dccccde1811093ecefde1753 /e-util/e-table.c
parent18bdb8b9205e70f725bf49a6f13dc3c2fe3fadf7 (diff)
downloadgsoc2013-evolution-7dcd0b44996ade2fc7713a927eb0ff44c5ff9fb2.tar.gz
gsoc2013-evolution-7dcd0b44996ade2fc7713a927eb0ff44c5ff9fb2.tar.zst
gsoc2013-evolution-7dcd0b44996ade2fc7713a927eb0ff44c5ff9fb2.zip
Update API documentation.
Diffstat (limited to 'e-util/e-table.c')
-rw-r--r--e-util/e-table.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/e-util/e-table.c b/e-util/e-table.c
index 4dc90bebf1..6d7ebbbcf3 100644
--- a/e-util/e-table.c
+++ b/e-util/e-table.c
@@ -1983,8 +1983,8 @@ e_table_construct_from_spec_file (ETable *e_table,
* e_table_new:
* @etm: The model for this table.
* @ete: An optional #ETableExtras. (%NULL is valid.)
* @spec: The spec.
* @state: An optional state. (%NULL is valid.)
*
* This function creates an #ETable from the given parameters. The
* #ETableModel is a table model to be represented. The #ETableExtras
@@ -2003,18 +2003,18 @@ e_table_construct_from_spec_file (ETable *e_table,
GtkWidget *
e_table_new (ETableModel *etm,
ETableExtras *ete,
- const gchar *spec,
- const gchar *state)
+ const gchar *spec_str,
+ const gchar *state_str)
{
ETable *e_table;
g_return_val_if_fail (E_IS_TABLE_MODEL (etm), NULL);
g_return_val_if_fail (ete == NULL || E_IS_TABLE_EXTRAS (ete), NULL);
- g_return_val_if_fail (spec != NULL, NULL);
+ g_return_val_if_fail (spec_str != NULL, NULL);
e_table = g_object_new (E_TYPE_TABLE, NULL);
- e_table = e_table_construct (e_table, etm, ete, spec, state);
+ e_table = e_table_construct (e_table, etm, ete, spec_str, state_str);
return GTK_WIDGET (e_table);
}
@@ -1983,8 +1983,8 @@ e_table_construct_from_spec_file (ETable *e_table,
* @etm: The model for this table.
* @ete: An optional #ETableExtras. (%NULL is valid.)
- * @spec: The spec.
- * @state: An optional state. (%NULL is valid.)
+ * @spec_str: The spec.
+ * @state_str: An optional state. (%NULL is valid.)
*
* This function creates an #ETable from the given parameters. The